use strict;
use warnings;

package ManySubs;

sub _sub_with_blocks {
    if (1) {
    if (1) {
    if (1) {
    if (1) {
        if (1) {
            if (1) {
                if (1) {
                    if (1) {
                        1;
    }
    }
    }
    }
    }
    }
    }
    }
    return;
}

sub _sub_01 {
    return;
}

sub _sub_02 {
    return;
}

sub _sub_03 {
    return;
}

sub _sub_04 {
    return;
}

sub _sub_05 {
    return;
}

sub _sub_06 {
    return;
}

sub _sub_07 {
    return;
}

sub _sub_08 {
    return;
}

sub _sub_09 {
    return;
}

sub _sub_10 {
    return;
}

sub _sub_11 {
    return;
}

1;
